@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "lbreakout.h"
+#include "config.h"
 #include "event.h"
 
 StkFont *help_caption_font = 0;
@@ -26,6 +27,8 @@ int side_count = 4;
 extern SDL_Surface *stk_display;
 extern SDL_Surface *extra_pic;
 extern SDL_Surface *brick_pic;
+extern int stk_quit_request;
+extern Config config;
 
 /*
 ====================================================================
@@ -42,7 +45,7 @@ void draw_title( )
 {
 	help_caption_font->align = STK_FONT_ALIGN_CENTER_X | STK_FONT_ALIGN_TOP;
 	stk_font_write( help_caption_font, 
-        stk_display, stk_display->w / 2, 20, STK_OPAQUE, "Quick Help" );
+        stk_display, stk_display->w / 2, 20, STK_OPAQUE, _("Quick Help") );
 }
 /*
 ====================================================================
@@ -57,7 +60,7 @@ void draw_footnote( int side )
 	stk_font_write( help_font, stk_display, 
         stk_display->w - 2, stk_display->h - 2, STK_OPAQUE, buf );
 	help_font->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_BOTTOM;
-	sprintf( buf, "<ESCAPE>: Quit  <LEFT BUTTON>: Next Page  <RIGHT BUTTON>: Previous Page" );
+	sprintf( buf, _("<ESCAPE>: Quit  <LEFT BUTTON>: Next Page  <RIGHT BUTTON>: Previous Page") );
 	stk_font_write( help_font, 
         stk_display, 2, stk_display->h - 2, STK_OPAQUE, buf );
 }
@@ -108,32 +111,32 @@ void draw_bonus_screen()
 	/* bonuses */
 	help_caption_font->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
 	stk_font_write( help_caption_font, 
-        stk_display, bonus_x, bonus_y - 30, STK_OPAQUE, "Bonuses:" );
-	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 0, 8,  "Expand paddle" );
-	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 0, 9,  "Extra life" );
-	draw_bonus_info( bonus_x + bonus_w * 2, bonus_y + bonus_h * 0, 10, "Sticky paddle" );
-	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 1, 15, "Plasma weapon" );
-	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 1, 2,  "200 - 10,000 points extra score" );
-	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 2, 12, "Extra ball" );
-	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 2, 11, "Energy balls (penetrate bricks)" );
-	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 3, 13, "Bonus floor" );
-	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 3, 18, "Deccelerate balls to minimum speed" );
-	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 4, 6,  "1,000 points extra score from bricks with no bonus" );
-	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 5, 19, "Instantly collect all bonuses and destroy all maluses" );
-	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 6, 25, "Explosive balls" );
-	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 6, 26, "Paddle attracts bonuses" );
+        stk_display, bonus_x, bonus_y - 30, STK_OPAQUE, _("Bonuses:") );
+	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 0, 8,  _("Expand paddle") );
+	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 0, 9,  _("Extra life") );
+	draw_bonus_info( bonus_x + bonus_w * 2, bonus_y + bonus_h * 0, 10, _("Sticky paddle") );
+	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 1, 15, _("Plasma weapon") );
+	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 1, 2,  _("200 - 10,000 points extra score") );
+	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 2, 12, _("Extra ball") );
+	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 2, 11, _("Energy balls (penetrate bricks)") );
+	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 3, 13, _("Bonus floor") );
+	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 3, 18, _("Deccelerate balls to minimum speed") );
+	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 4, 6,  _("1,000 points extra score from bricks with no bonus") );
+	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 5, 19, _("Instantly collect all bonuses and destroy all penalties") );
+	draw_bonus_info( bonus_x + bonus_w * 0, bonus_y + bonus_h * 6, 25, _("Explosive balls") );
+	draw_bonus_info( bonus_x + bonus_w * 1, bonus_y + bonus_h * 6, 26, _("Paddle attracts bonuses") );
     
-	/* maluses */
+	/* penalties */
 	stk_font_write( help_caption_font, stk_display, 
-        malus_x, malus_y - 30, STK_OPAQUE, "Maluses:" );
-	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 0, 7,  "Shrink paddle" );
-	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 3, 17,  "Accelerate balls" );
-	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 1, 14,  "Freeze paddle" );
-	draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 1, 21,  "Random ball reflection at bricks" );
-	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 2, 20,  "Darkness" );
-	draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 2, 27,  "Paddle attracts maluses" );
-	draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 0, 22,  "Paddle disappears when not moving" );
-	draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 3, 28,  "40% chance that a ball doesn't damage brick" );
+        malus_x, malus_y - 30, STK_OPAQUE, _("Penalties:") );
+	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 0, 7,  _("Shrink paddle") );
+	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 3, 17,  _("Accelerate balls") );
+	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 1, 14,  _("Freeze paddle") );
+	draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 1, 21,  _("Random ball reflection at bricks") );
+	draw_bonus_info( malus_x + malus_w * 0, malus_y + malus_h * 2, 20,  _("Darkness") );
+	draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 2, 27,  _("Paddle attracts penalties") );
+	draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 0, 22,  _("Paddle disappears when not moving") );
+    draw_bonus_info( malus_x + malus_w * 1, malus_y + malus_h * 3, 28,  /* xgettext:no-c-format */ _("40% chance that a ball doesn't damage brick") );
 	
 	draw_footnote( 1 );
 	
@@ -163,26 +166,26 @@ void draw_hints_screen()
 
 	help_caption_font->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
 	stk_font_write( help_caption_font, stk_display, 
-        hint_x, hint_y - 40, STK_OPAQUE, "Hints:" );
+        hint_x, hint_y - 40, STK_OPAQUE, _("Hints:") );
 	
-	draw_hint( hint_x, hint_y + hint_h * 0, "<<'In Game'-Keys>>" );
-	draw_hint( hint_x, hint_y + hint_h * 1, " p      Pause game. (and enter chatroom in network game)" );
-	draw_hint( hint_x, hint_y + hint_h * 2, " s      Enable/Disable sound." );
-	draw_hint( hint_x, hint_y + hint_h * 3, " a      Change animation level (off/low/high)." );
-	draw_hint( hint_x, hint_y + hint_h * 4, " f      Switch fullscreen/windowed mode." );
-	draw_hint( hint_x, hint_y + hint_h * 5, "        NOTE: Changing resolution takes a while so this is done best" );
-	draw_hint( hint_x, hint_y + hint_h * 6, "        when game's paused." );
-	draw_hint( hint_x, hint_y + hint_h * 7, " r      Restart level." );
-	draw_hint( hint_x, hint_y + hint_h * 8, " d      Disintegrate single bricks. (AddOn's only)" );
-	draw_hint( hint_x, hint_y + hint_h * 9, " w      Warp to next level after enough bricks where cleared. (AddOn's only)" );
-	draw_hint( hint_x, hint_y + hint_h * 10, " Shift  Shows highest score of set instead of your score as long as you" );
-	draw_hint( hint_x, hint_y + hint_h * 11, "        hold it down." );
-	draw_hint( hint_x, hint_y + hint_h * 12, " Tab    Take a screenshot." );
-	draw_hint( hint_x, hint_y + hint_h * 13, " Esc    Quit game." );
+	draw_hint( hint_x, hint_y + hint_h * 0, _("<<'In Game'-Keys>>") );
+	draw_hint( hint_x, hint_y + hint_h * 1, _(" p      Pause game. (and enter chatroom in network game)") );
+	draw_hint( hint_x, hint_y + hint_h * 2, _(" s      Enable/Disable sound.") );
+	draw_hint( hint_x, hint_y + hint_h * 3, _(" a      Change animation level (off/low/high).") );
+	draw_hint( hint_x, hint_y + hint_h * 4, _(" f      Switch fullscreen/windowed mode.") );
+	draw_hint( hint_x, hint_y + hint_h * 5, _("        NOTE: Changing resolution takes a while so this is done best") );
+	draw_hint( hint_x, hint_y + hint_h * 6, _("        when game's paused.") );
+	draw_hint( hint_x, hint_y + hint_h * 7, _(" r      Restart level.") );
+	draw_hint( hint_x, hint_y + hint_h * 8, _(" d      Disintegrate single bricks. (AddOn's only)") );
+	draw_hint( hint_x, hint_y + hint_h * 9, _(" w      Warp to next level after enough bricks where cleared. (AddOn's only)") );
+	draw_hint( hint_x, hint_y + hint_h * 10, _(" Shift  Shows highest score of set instead of your score as long as you") );
+	draw_hint( hint_x, hint_y + hint_h * 11, _("        hold it down.") );
+	draw_hint( hint_x, hint_y + hint_h * 12, _(" Tab    Take a screenshot.") );
+	draw_hint( hint_x, hint_y + hint_h * 13, _(" Esc    Quit game.") );
 
-	draw_hint( hint_x, hint_y + hint_h * 15, "Pressing the left or right mouse button will fire attached balls either" );
-	draw_hint( hint_x, hint_y + hint_h * 16, "to the left or right direction if 'Ball Fire Angle' in 'Advanced Options'" );
-	draw_hint( hint_x, hint_y + hint_h * 17, "is not set to 'Random'." );
+	draw_hint( hint_x, hint_y + hint_h * 15, _("Pressing the left or right mouse button will fire attached balls either") );
+	draw_hint( hint_x, hint_y + hint_h * 16, _("to the left or right direction if 'Ball Fire Angle' in 'Advanced Options'") );
+	draw_hint( hint_x, hint_y + hint_h * 17, _("is not set to 'Random'.") );
 	
 	draw_footnote( 3 );
 	
@@ -203,23 +206,23 @@ void draw_ingame_hints_screen()
 
 	help_caption_font->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
 	stk_font_write( help_caption_font, stk_display, 
-        extra_x, extra_y - 30, STK_OPAQUE, "Neutral Power-Ups:" );
+        extra_x, extra_y - 30, STK_OPAQUE, _("Neutral Power-Ups:") );
 
-    draw_bonus_info( extra_x, extra_y + extra_h * 0, 16, "Any of the listed bonuses/maluses." );
-    draw_bonus_info( extra_x, extra_y + extra_h * 1, 23, "Resets all active bonuses and maluses." );
-    draw_bonus_info( extra_x, extra_y + extra_h * 2, 24, "Adds 7 seconds to all active bonuses/maluses." );
+    draw_bonus_info( extra_x, extra_y + extra_h * 0, 16, _("Any of the listed bonuses/penalties.") );
+    draw_bonus_info( extra_x, extra_y + extra_h * 1, 23, _("Resets all active bonuses and penalties.") );
+    draw_bonus_info( extra_x, extra_y + extra_h * 2, 24, _("Adds 7 seconds to all active bonuses/penalties.") );
     
 	help_caption_font->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
 	stk_font_write( help_caption_font, stk_display, 
-        brick_x, brick_y - 30, STK_OPAQUE, "Special Bricks:" );
+        brick_x, brick_y - 30, STK_OPAQUE, _("Special Bricks:") );
 
-    draw_brick_info( brick_x, brick_y + brick_h * 0, 0, "Indestructible." );
-    draw_brick_info( brick_x, brick_y + brick_h * 1, 1, "May only be destroyed by energy ball else it's indestructible." );
-    draw_brick_info( brick_x, brick_y + brick_h * 2, 2, "As above and balls are reflected randomly at this brick." );
-    draw_brick_info( brick_x, brick_y + brick_h * 3, 5, "Needs three hits to be destroyed." );
-    draw_brick_info( brick_x, brick_y + brick_h * 4, 9, "As above and regenerates durability every 4 seconds." );
-    draw_brick_info( brick_x, brick_y + brick_h * 5, 18, "Explodes and destroys all nearby bricks." );
-    draw_brick_info( brick_x, brick_y + brick_h * 6, 19, "Creates up to 8 bricks on destruction." );
+    draw_brick_info( brick_x, brick_y + brick_h * 0, 0, _("Indestructible.") );
+    draw_brick_info( brick_x, brick_y + brick_h * 1, 1, _("May only be destroyed by energy ball else it's indestructible.") );
+    draw_brick_info( brick_x, brick_y + brick_h * 2, 2, _("As above and balls are reflected randomly at this brick.") );
+    draw_brick_info( brick_x, brick_y + brick_h * 3, 5, _("Needs three hits to be destroyed.") );
+    draw_brick_info( brick_x, brick_y + brick_h * 4, 9, _("As above and regenerates durability every 4 seconds.") );
+    draw_brick_info( brick_x, brick_y + brick_h * 5, 18, _("Explodes and destroys all nearby bricks.") );
+    draw_brick_info( brick_x, brick_y + brick_h * 6, 19, _("Creates up to 8 bricks on destruction.") );
 
     draw_footnote( 2 );
 	
@@ -243,29 +246,29 @@ void draw_trouble_screen()
 
 	help_caption_font->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
 	stk_font_write( help_caption_font, stk_display, 
-        trouble_x, trouble_y - 40, STK_OPAQUE, "Troubleshooting:" );
+        trouble_x, trouble_y - 40, STK_OPAQUE, _("Troubleshooting:") );
 	
-	draw_trouble( trouble_x, trouble_y + trouble_h * 0, "* In fullscreen mode the window keeps it size just adding a black frame?" );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 1, "  - Maybe you do not have 640x480 as resolution available? Check your" );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 2, "    X configuration." );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 3, "* Sounds seem to be out of sync and are played with some delay?" );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 4, "  - Set SDL_AUDIODRIVER to dma (export SDL_AUDIODRIVER=dma). If this results" );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 5, "    in a lot of errors killing artsd (or esd) may help." );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 6, "* LBreakout2 gets mute while playing when switching on/off sounds?" );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 7, "  - SDL_mixer seems to mute active channels. You shouldn't enable/disable" );
-	draw_trouble( trouble_x, trouble_y + trouble_h * 8, "    sounds to often as you'll propably loose all channels then." );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 0, _("* In fullscreen mode the window keeps it size just adding a black frame?") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 1, _("  - Maybe you do not have 640x480 as resolution available? Check your") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 2, _("    X configuration.") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 3, _("* Sounds seem to be out of sync and are played with some delay?") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 4, _("  - Set SDL_AUDIODRIVER to dma (export SDL_AUDIODRIVER=dma). If this results") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 5, _("    in a lot of errors killing artsd (or esd) may help.") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 6, _("* LBreakout2 gets mute while playing when switching on/off sounds?") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 7, _("  - SDL_mixer seems to mute active channels. You shouldn't enable/disable") );
+	draw_trouble( trouble_x, trouble_y + trouble_h * 8, _("    sounds to often as you'll propably loose all channels then.") );
 	
 	help_caption_font->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
 	stk_font_write( help_caption_font, stk_display, 
-        manual_x, manual_y - 40, STK_OPAQUE , "Manual:");
-	draw_trouble( manual_x, manual_y + manual_h * 0, "This is just a quick help with the most important facts about LBreakout2." );
-	draw_trouble( manual_x, manual_y + manual_h * 1, "If you want more and better information check out the manual installed to" );
-	draw_trouble( manual_x, manual_y + manual_h * 2, "/usr/doc/lbreakout2 or the online version at http://lgames.sf.net." );
-	draw_trouble( manual_x, manual_y + manual_h * 3, "And if you have questions (not answered by the manual) or you found a bug" );
-	draw_trouble( manual_x, manual_y + manual_h * 4, "or you just want to drop a general note about LBreakout2 just mail to:" );
-	draw_trouble( manual_x, manual_y + manual_h * 5, "  kulkanie@gmx.net" );
-	draw_trouble( manual_x, manual_y + manual_h * 6, "                         Enjoy the game!" );
-	draw_trouble( manual_x, manual_y + manual_h * 6 + 10, "                                                 Michael Speck" );
+        manual_x, manual_y - 40, STK_OPAQUE , _("Manual:"));
+	draw_trouble( manual_x, manual_y + manual_h * 0, _("This is just a quick help with the most important facts about LBreakout2.") );
+	draw_trouble( manual_x, manual_y + manual_h * 1, _("If you want more and better information check out the manual installed to") );
+	draw_trouble( manual_x, manual_y + manual_h * 2, _("/usr/doc/lbreakout2 or the online version at http://lgames.sf.net.") );
+	draw_trouble( manual_x, manual_y + manual_h * 3, _("And if you have questions (not answered by the manual) or you found a bug") );
+	draw_trouble( manual_x, manual_y + manual_h * 4, _("or you just want to drop a general note about LBreakout2 just mail to:") );
+	draw_trouble( manual_x, manual_y + manual_h * 5, _("  kulkanie@gmx.net") );
+	draw_trouble( manual_x, manual_y + manual_h * 6, _("                         Enjoy the game!") );
+	draw_trouble( manual_x, manual_y + manual_h * 6 + 10, _("                                                 Michael Speck") );
 	
 	draw_footnote( 4 );
 	
@@ -286,9 +289,13 @@ Load/delete help resources.
 void help_create()
 {
     help_font = stk_font_load( SDL_SWSURFACE, "f_small_yellow.png" );
+    SDL_SetColorKey( help_font->surface, SDL_SRCCOLORKEY, 
+            stk_surface_get_pixel( help_font->surface, 0,0 ) );	
     help_caption_font = stk_font_load( SDL_SWSURFACE, "f_yellow.png" );
-	/* background -- will be filled when running help */
-	help_bkgnd = stk_surface_create( SDL_SWSURFACE, stk_display->w, stk_display->h );
+    SDL_SetColorKey( help_caption_font->surface, SDL_SRCCOLORKEY, 
+            stk_surface_get_pixel( help_caption_font->surface, 0,0 ) );	
+    /* background -- will be filled when running help */
+    help_bkgnd = stk_surface_create( SDL_SWSURFACE, stk_display->w, stk_display->h );
     SDL_SetColorKey( help_bkgnd, 0, 0 );
 }
 void help_delete()
@@ -303,6 +310,15 @@ void help_delete()
 Run help.
 ====================================================================
 */
+static void help_draw_side( int side_id )
+{
+    switch ( side_id ) {
+        case 0: draw_bonus_screen(); break;
+        case 2: draw_hints_screen(); break;
+        case 1: draw_ingame_hints_screen(); break;
+        case 3: draw_trouble_screen(); break;
+    }
+}
 void help_run()
 {
 	int leave = 0;
@@ -320,9 +336,10 @@ void help_run()
     stk_surface_blit( stk_display, 0,0,-1,-1, help_bkgnd, 0,0 );
 		
 	draw_bonus_screen();
-	while ( !leave ) {
+	while ( !leave && !stk_quit_request) {
 		SDL_WaitEvent( &event );
 		switch ( event.type ) {
+            case SDL_QUIT: stk_quit_request = 1; break;
 			case SDL_KEYDOWN:
 				switch ( event.key.keysym.sym ) {
 					case SDLK_ESCAPE: leave = 1; break;
@@ -336,13 +353,13 @@ void help_run()
 							cur_side--;
 							if ( cur_side < 0 ) cur_side = side_count - 1;
 						}
-						switch ( cur_side ) {
-							case 0: draw_bonus_screen(); break;
-							case 2: draw_hints_screen(); break;
-							case 1: draw_ingame_hints_screen(); break;
-							case 3: draw_trouble_screen(); break;
-						}
+                        help_draw_side(cur_side);
 						break;
+                    case SDLK_f:
+						config.fullscreen = !config.fullscreen;
+                        stk_display_apply_fullscreen( config.fullscreen );
+                        help_draw_side(cur_side);
+                        break;
 					default: break;
 				}
 				break;
@@ -355,12 +372,7 @@ void help_run()
 					cur_side--;
 					if ( cur_side < 0 ) cur_side = side_count - 1;
 				}
-				switch ( cur_side ) {
-					case 0: draw_bonus_screen(); break;
-					case 2: draw_hints_screen(); break;
-					case 1: draw_ingame_hints_screen(); break;
-					case 3: draw_trouble_screen(); break;
-				}
+                help_draw_side(cur_side);
 				break;
 			default: break;
 		}
@@ -373,5 +385,4 @@ void help_run()
 	
     /* reset the relative position so paddle wont jump */
     SDL_GetRelativeMouseState(0,0);
-
 }
