@@ -20,10 +20,6 @@
 #include <sys/stat.h>
 #include <dirent.h>
 
-#ifdef HAVE_CONFIG_H
-#include "../config.h"
-#endif
-
 #include "lbreakout.h"
 #include "config.h"
 #include "theme.h"
@@ -704,5 +700,5 @@ void theme_get_info( char *theme_name, char *text, int limit )
                 break;
     }
     else
-        strcpy_lt( text, "NO INFO AVAILABLE", limit );
+        strcpy_lt( text, _("NO INFO AVAILABLE"), limit );
 }
