@@ -144,5 +144,12 @@ fired the result may differ from paddle::attached_ball_count!
 */
 int balls_detach_from_paddle( Paddle *paddle, int dir );
   
+/*
+====================================================================
+Clear contents of target.
+====================================================================
+*/
+void ball_clear_target( Target *t );
+
 #endif
 
