@@ -55,6 +55,45 @@ static GameDiff net_diffs[DIFF_COUNT] = {
 
 /***** LOCAL FUNCTIONS *****************************************************/
 
+static void game_setup_title_and_author( Game *game, Level *level )
+{
+  switch (level->type)
+    {
+    case LT_NORMAL:
+      snprintf( game->title, 32, "%s", level->name );
+      snprintf( game->author, 32, "%s", level->author );
+      break;
+    case LT_JUMPING_JACK:
+      snprintf( game->title, 32, _("Jumping Jack") );
+      snprintf( game->author, 32, _("Bonus Level") );
+      break;
+    case LT_OUTBREAK:
+        snprintf( game->title, 32, _("Outbreak") );
+        snprintf( game->author, 32, _("Bonus Level") );
+        break;
+    case LT_BARRIER:
+        snprintf( game->title, 32, _("Barrier") );
+        snprintf( game->author, 32, _("Bonus Level") );
+        break;
+    case LT_SITTING_DUCKS:
+        snprintf( game->title, 32, _("Sitting Ducks") );
+        snprintf( game->author, 32, _("Bonus Level") );
+        break;
+    case LT_HUNTER:
+        snprintf( game->title, 32, _("Hunter") );
+        snprintf( game->author, 32, _("Bonus Level") );
+        break;
+    case LT_DEFENDER:
+        snprintf( game->title, 32, _("Defender") );
+        snprintf( game->author, 32, _("Bonus Level") );
+        break;
+    default:
+      snprintf( game->title, 32, _("Unknown Level Type") );
+      snprintf( game->author, 32, "???" );
+      break;
+    }
+}
+
 /***** PUBLIC FUNCTIONS ****************************************************/
 
 /* create/delete game context */
@@ -118,7 +157,11 @@ void game_delete( Game **_game )
 	if ( game->extras ) list_delete( game->extras );
 	if ( game->balls ) list_delete( game->balls );
 
-	free( game );
+    /* delete bonus level stuff */
+    if (game->blDuckPositions) free(game->blDuckPositions);
+	if (game->blInvaders) free(game->blInvaders);
+    
+    free( game );
 	*_game = 0;
 }
 
@@ -127,46 +170,59 @@ void game_delete( Game **_game )
  * while playing. */
 void game_init( Game *game, Level *level )
 {
-	int i;
-	Ball *ball;
+  int i;
+  Ball *ball;
 
-	game->level_over = 0;
-	
-	/* initiate level data */
-	snprintf( game->title, 32, level->name );
-	snprintf( game->author, 32, level->author );
-	bricks_init( game, game->game_type, level, game->diff->score_mod, game->rel_warp_limit );
-	if ( game->game_type == GT_LOCAL || game->brick_count > 0 )
-		game->level_type = LT_NORMAL;
-	else
-		game->level_type = LT_PINGPONG;
-	memset( game->extra_active, 0, sizeof( game->extra_active ) );
-	memset( game->extra_time, 0, sizeof( game->extra_time ) );
+  game->level_over = 0;
+  game->isBonusLevel = 0;
+  game->totalBonusLevelScore = 0;
 
-	/* set ball speed */
-	game->ball_v = game->ball_v_min;
-	game->speedup_level = 0;
+  /* set title and author */
+  game_setup_title_and_author( game, level );
+
+  /* set level type. is level::type except for normal level with no bricks: pingpong */
+  if (level->type==LT_NORMAL && game->game_type == GT_NETWORK && game->brick_count == 0 )
+    game->level_type = LT_PINGPONG;
+  else
+  {
+      game->level_type = level->type;
+      if (game->level_type!=LT_NORMAL) game->isBonusLevel = 1;
+  }
+  
+  /* clear extras */
+  memset( game->extra_active, 0, sizeof( game->extra_active ) );
+  memset( game->extra_time, 0, sizeof( game->extra_time ) );
+
+  /* set ball speed */
+  game->ball_v = game->ball_v_min;
+  game->speedup_level = 0;
 	
-        /* clear maxballspeed_request */
-        if ( game->game_type == GT_LOCAL )
-        {
-            cur_game->paddles[0]->maxballspeed_request = 0;
-            cur_game->paddles[0]->maxballspeed_request_old = 0;
-        }
+  /* clear maxballspeed_request */
+  if ( game->game_type == GT_LOCAL )
+    {
+      cur_game->paddles[0]->maxballspeed_request = 0;
+      cur_game->paddles[0]->maxballspeed_request_old = 0;
+    }
         
-	/* attach one ball to each paddle */
-    list_clear( game->balls );
-	for ( i = 0; i < game->paddle_count; i++ ) {
-		if ( game->paddles[i]->type == PADDLE_BOTTOM )
-			ball = ball_create((game->paddles[i]->w - ball_w) / 2, -ball_dia );
-		else
-			ball = ball_create((game->paddles[i]->w - ball_w) / 2, game->paddles[i]->h );
-		ball->attached = 1;
-		ball->paddle = game->paddles[i];
-		ball->paddle->attached_ball_count = 1;
-		ball_set_random_angle( ball, game->ball_v );
-		list_add( game->balls, ball );
-	}
+  /* attach one ball to each paddle */
+  list_clear( game->balls );
+  for ( i = 0; i < game->paddle_count; i++ ) {
+    if ( game->paddles[i]->type == PADDLE_BOTTOM )
+      ball = ball_create((game->paddles[i]->w - ball_w) / 2, -ball_dia );
+    else
+      ball = ball_create((game->paddles[i]->w - ball_w) / 2, game->paddles[i]->h );
+    ball->attached = 1;
+    ball->paddle = game->paddles[i];
+    ball->paddle->attached_ball_count = 1;
+    ball_set_random_angle( ball, game->ball_v );
+    list_add( game->balls, ball );
+  }
+  
+  /* do bricks as last to have influence on balls to keep bonus level stuff in one place */
+  /* setup bricks (from level data or from special level type; this includes setting the
+     bonus level data if any */
+  bricks_init( game, game->game_type, level, game->diff->score_mod, game->rel_warp_limit );
+    
 }
 
 /* reset level/in_game data */
@@ -291,7 +347,7 @@ void game_update( int ms )
 		if ( cur_game->balls->count == 0 ) cur_game->level_over = 1;
 	} else {
 		/* network game */
-		if ( cur_game->level_type == LT_NORMAL ) {
+		if ( cur_game->level_type != LT_PINGPONG ) {
 			if ( cur_game->bricks_left == 0 ) cur_game->level_over = 1;
 		} 
 		else
@@ -303,7 +359,7 @@ void game_update( int ms )
 	/* if so, determine winner */
 	if ( cur_game->level_over ) {
 		if ( cur_game->game_type == GT_LOCAL ) {
-			if ( cur_game->bricks_left == 0 )
+			if ( cur_game->bricks_left == 0 || cur_game->isBonusLevel )
 				cur_game->winner = PADDLE_BOTTOM; /* praise */
 			else
 				cur_game->winner = PADDLE_TOP; /* swear */
@@ -436,4 +492,3 @@ void game_update_stats( int id, GameStats *stats )
 		stats->losses++;
 	stats->played_rounds++;
 }
-
