@@ -31,7 +31,10 @@
 
 /***** PUBLIC FUNCTIONS ****************************************************/
 
-/* create/delete game context */
+/* create/delete game context 
+   game_type is either GT_LOCAL, GT_NETWORK_CLIENT, GT_NETWORK_SERVER.
+   if it is GT_NETWORK_..., it is changed to GT_NETWORK while setting 
+   isServerSidedGame */
 Game *game_create( int game_type, int diff, int rel_warp_limit );
 void game_delete( Game **game );
 
