@@ -422,7 +422,7 @@ void gui_edit_set_text( GuiWidget *widget, char *text )
 {
     if ( widget->type != GUI_EDIT ) return;
     /* copy text */
-    snprintf( widget->spec.edit.buffer, widget->spec.edit.size + 1, text );
+    snprintf( widget->spec.edit.buffer, widget->spec.edit.size + 1, "%s", text );
     widget->spec.edit.length = strlen( widget->spec.edit.buffer );
     /* reset */
     /* first character in first line */
@@ -456,7 +456,7 @@ int gui_edit_get_text(
     if ( length > limit )
         length = limit;
     if ( length )
-        snprintf( buffer, limit, widget->spec.edit.buffer );
+        snprintf( buffer, limit, "%s", widget->spec.edit.buffer );
     else
         buffer[0] = 0;
     return 1;
